@@ -7,7 +7,7 @@ from cloudant import CouchDB
 from cloudant.error import CloudantDatabaseException
 
 from ...settings import COUCHDB_DATASTORE_USER, COUCHDB_DATASTORE_PASSWORD, COUCHDB_DATASTORE_URL, \
-                        COUCHDB_DATASTORE_DATABASE_NAME, DJANGO_PROJECT_BACKUP_MODE
+                        COUCHDB_DATASTORE_DATABASE_NAME, BACKUP_MODE
 
 
 def response_to_json_dict(response, **kwargs):
@@ -30,7 +30,7 @@ class DBAdapter:
     """
 
     def get_database_name(self):
-        if DJANGO_PROJECT_BACKUP_MODE == 'full':
+        if BACKUP_MODE == 'full':
             now = timezone.now()
             return '{}__{}'.format(COUCHDB_DATASTORE_DATABASE_NAME,
                                    now.strftime("%Y_%m_%d"))
